
=============================
The requirements for `csdmpy`
=============================

The list of packages dependencies for `csdmpy` module

- `numpy>=1.10.1 <https://www.numpy.org>`_ (for handling n-dimensional arrays)
- setuptools>=27.3
- `requests>=2.21.0 <http://docs.python-requests.org/en/master/>`_ (for downloading files from server)
- `astropy>=3.0 <http://www.astropy.org>`_ (for astropy units module)
- `matplotlib>=3.0 <https://matplotlib.org>`_ (for rendering plots)
